<?php
/*******************************************************************************
 * Copyright (C) 2007 Easter-eggs
 * http://ldapsaisie.labs.libre-entreprise.org
 *
 * Author: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

require('config.LSobjects.common.php');

$GLOBALS['LSobjects']['supannOrg'] = array (
  'objectclass' => array(
    'organization',
    'eduOrg',
    'supannOrg',
    'supannEntite',
  ),
  'rdn' => 'supannCodeEntite',
  'container_dn' => 'ou=structures',
  'display_name_format' => '%{o}',
  'label' => 'Establishments',
  'displayAttrName' => true,

  // triggers
  'before_delete' => 'supannCheckEntityCouldBeDeleted',

  'customActions' => array (
    'showTechInfo' => array (
      'function' => 'showTechInfo',
      'label' => 'Show technical information',
      'hideLabel' => True,
      'noConfirmation' => true,
      'disableOnSuccessMsg' => true,
      'icon' => 'tech_info',
      'rights' => array (
        'admin',
      ),
    ),
  ),

  // LSform
  'LSform' => array (
    'ajaxSubmit' => 1,
    // Layout
    'layout' => array (
      'infos' => array(
        'label' => 'Information',
        'args' => array (
          'o',
          'description',
          'l',
          'supannEtablissement',
          'supannTypeEntite',
          'supannCodeEntite',
          'supannRefId',
        ),
      ),
      'com' => array (
        'label' => 'Communication',
        'args' => array (
          'postalAddress',
          'telephoneNumber',
          'facsimileTelephoneNumber',
          'labeledURI',
          'eduOrgHomePageURI',
          'eduOrgSuperiorURI',
          'eduOrgWhitePagesURI',
        ),
      ),
    ),
  ),

  // LSrelation
  'LSrelation' => array(
    'children' => array(
      'label' => 'Children entities',
      'emptyText' => "Have any child entity.",
      'LSobject' => 'supannEntite',
      'linkAttribute' => 'supannCodeEntiteParent',
      'linkAttributeValue' => 'supannCodeEntite',
      'canEdit_attribute' => 'supannCodeEntiteParent',
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
    ),
    'godfather' => array(
      'label' => 'Godfather of ...',
      'emptyText' => "Doesn't sponsor anybody.",
      'LSobject' => "supannPerson",
      'linkAttribute' => "supannParrainDN",
      'linkAttributeValue' => "dn",
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
    ),
  ),

  'LSsearch' => array (
    'attrs' => array (
      'o',
      'l',
      'description',
      'supannCodeEntite',
      'supannRefId',
      'telephoneNumber',
      'postalAddress',
    ),
  ),

  'attrs' => array_merge($common_entity_attrs, array (
    /* ----------- start -----------*/
    'o' => array (
      'label' => "Name",
      'ldap_type' => 'ascii',
      'html_type' => 'text',
      'required' => 1,
      'validation' => array (
        array (
          'object_type' => 'supannOrg',
          'filter' => 'o=%{val}',
          'result' => 0
        ),
      ),
      'view' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'form' => array (
        'modify' => 1,
        'create' => 1
      ),
      'dependAttrs' => array (
        'eduOrgLegalName',
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'supannEtablissement' => array (
      'label' => 'Establishment',
      'ldap_type' => 'ascii',
      'html_type' => 'supannEtablissement',
      'required' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'view' => 1,
      'form' => array (
        'modify' => 1,
        'create' => 1,
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'eduOrgHomePageURI' => array (
      'label' => "Website URL",
      'ldap_type' => 'ascii',
      'html_type' => 'url',
      'check_data' => array (
        'regex' => array(
          'params' => array(
            'regex' => '/^https?:\/\/.*/',
          ),
          'msg' => "Invalid URL.",
        ),
      ),
      'multiple' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'view' => 1,
      'form' => array (
        'modify' => 1,
        'create' => 1
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'eduOrgLegalName' => array (
      'label' => "Legal name",
      'ldap_type' => 'ascii',
      'html_type' => 'text',
      'multiple' => 0,
      'generate_value_format' => '%{o}',
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'eduOrgSuperiorURI' => array (
      'label' => 'Parent organization website URL',
      'ldap_type' => 'ascii',
      'html_type' => 'url',
      'check_data' => array (
        'regex' => array(
          'params' => array(
            'regex' => '^/https?:\/\/.*/',
          ),
          'msg' => "Invalid URL.",
        ),
      ),
      'multiple' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'view' => 1,
      'form' => array (
        'modify' => 1,
        'create' => 1
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'eduOrgWhitePagesURI' => array (
      'label' => "White pages website URL",
      'ldap_type' => 'ascii',
      'html_type' => 'url',
      'check_data' => array (
        'regex' => array(
          'params' => array(
            'regex' => '/^https?:\/\/.*/',
          ),
          'msg' => "Invalid URL.",
        ),
      ),
      'multiple' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'view' => 1,
      'form' => array (
        'modify' => 1,
        'create' => 1
      ),
    ),
    /* ----------- end -----------*/

    /* ----------- start -----------*/
    'l' => array (
      'label' => "City",
      'ldap_type' => 'ascii',
      'html_type' => 'text',
      'multiple' => 1,
      'rights' => array(
        'admin' => 'w',
        'sysaccount' => 'r',
      ),
      'view' => 1,
      'form' => array (
        'modify' => 1,
        'create' => 1
      ),
    ),
    /* ----------- end -----------*/
  )), // End of attrs & array_merge
);

@include('config.LSobjects.phpLdapAdmin.php');
