<?php
/*******************************************************************************
 * Copyright (C) 2007 Easter-eggs
 * http://ldapsaisie.labs.libre-entreprise.org
 *
 * Author: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

// Load Supann configuration file
require('config.supann.inc.php');

// Configuration LDAP Saisie :
$GLOBALS['LSconfig'] = array(
  'NetLDAP2' => '/usr/share/php/Net/LDAP2.php',
  'Smarty' => '/usr/share/php/smarty3/Smarty.class.php',
  'ConsoleTable' => '/usr/share/php/Console/Table.php',
  'public_root_url' => '/',
  'lang' => 'fr_FR',
  'encoding' => 'UTF8',
  'cacheLSprofiles' => true,
  'cacheSubDn' => true,
  'cacheSearch' => true,
  'globalSearch' => true,
  'keepLSsessionActive' => true,
  'ldap_servers' => array(),
);

foreach ($supann_configs as $idx => $supann_config) {
  $ldap_config = $supann_config['ldap_config'];
  $basedn = $ldap_config['basedn'];
  $GLOBALS['LSconfig']['ldap_servers'][$idx] = array (
    'name' => $supann_config['name'],
    'ldap_config'=> $ldap_config,
    'useUserCredentials' => true,
    'globals' => $supann_config['globals'],
    'LSauth' => array (
      //'method' => 'basic', // Auth method : basic(default), HTTP, CAS or anonymous
      'LSobjects' => array(
        'supannPerson' => array(
          'filter' => '(|(uid=%{user})(mail=%{user})(supannAliasLogin=%{user}))',
          'password_attribute' => 'userPassword',
        ),
        'sysaccount',
      ),
      //'allow_multi_match' => false, // Allow username multiple match (default: false)
    ),
    'LSprofiles' => array (
      'admin' => array (
        'label' => 'Administrator',
        $basedn => array (
          'cn=admin,ou=groups,' . $basedn => array (
            'attr_value' => '%{dn}',
            'attr' => 'member',
            'LSobject' => 'supannGroup',
          ),
        ),
        'LSobjects' => array (
          'supannGroup2' => array(
            'attr' => 'supannGroupeAdminDN',
            'attr_value' => '%{dn}',
            'LSobject' => 'supannGroup',
          ),
          'supannGroup' => array(
            'filters' => array(
              array(
                'basedn' => $basedn,
                'attr' => 'member',
                'attr_value' => '%{dn}',
                'LSobject' => 'supannGroup',
              ),
              array(
                'basedn' => $basedn,
                'attr' => 'supannGroupeAdminDN',
                'attr_value' => '%{dn}',
                'LSobject' => 'supannGroup',
              ),
            ),
          ),
        ),
      ),
      'owner' => array (
        'label' => 'Group owner',
        'LSobjects' => array (
           'supannGroup' => array(
               'attr' => 'owner',
               'attr_value' => '%{dn}',
           ),
        ),
      ),
      'reader' => array (
        'label' => 'Group reader',
        'LSobjects' => array (
           'supannGroup' => array(
               'attr' => 'supannGroupeLecteurDN',
               'attr_value' => '%{dn}',
           ),
        ),
      ),
    ),
    'cacheLSprofiles' => false,
    'cacheSearch' => true,
    'LSaccess' => array(
      'supannPerson',
      'supannGroup',
      'supannOrg',
      'supannEntite',
      'sysaccount',
    ),
    'emailSender' => 'ldapsaisie-noreply@'.$supann_config['domain_name'],
  );

  if (defined('LS_SUPANN_ENABLE_PPOLICY') && constant('LS_SUPANN_ENABLE_PPOLICY')) {
    $GLOBALS['LSconfig']['ldap_servers'][$idx]['LSaccess'][] = 'pwdPolicy';
  }
}

// Interface
// Theme Black
//define('LS_THEME','black');
//define('LS_TEMPLATES_DIR', 'templates/default');

// Theme Default
define('LS_THEME','default');
define('LS_TEMPLATES_DIR', 'templates');
define('LS_IMAGES_DIR', 'images');
define('LS_CSS_DIR', 'css');

//Debug
define('LSdebug',false);

// Logging
$GLOBALS['LSlog']['handlers'] = array (
  array (
    'handler' => 'file',
    'path' => '/var/log/ldapsaisie/ldapsaisie.log',
    //'level' => 'DEBUG',
    //'enabled' => false, // Uncomment to disable this handler
    // Filter on specific loggers
    //'loggers' => array('LSurl', 'LSlang'),
    'excluded_loggers' => array('generate_lang_file', 'generate_ldapsaisie_pot'),
    // Default formats
    //'format' => '%{requesturi} - %{remoteaddr} - %{ldapservername} - %{authuser} - %{level} - %{message}',
    //'cli_format' => '%{clibinpath} - %{level} - %{message}',
    //'datetime_prefix' => true,            // Prefix message with datetime ?
    //'datetime_format' => 'Y/m/d H:i:s',   // Datetime prefix format (see php date() function)
  ),
  array (
    'handler' => 'file',
    'path' => '/var/log/ldapsaisie/debug.log',
    'level' => 'DEBUG',
    'enabled' => $debug,
  ),
  array (
    'handler' => 'email', // Email handler (each logged message generated an email)
    'level' => 'FATAL',
    'recipient' => 'root@localhost', // Email recipient
  ),
  /*
  array (
    'handler' => 'syslog', // Syslog handler
    //'priority' => 'WARNING', // Force priority : EMERG, ALERT, CRITICAL, ERROR, WARNING, NOTICE, INFO, DEBUG
  ),
  */
  /*
  array (
    'handler' => 'system', // System logging (using PHP error_log)
    'level' => 'ERROR',
  ),
  */
);
$GLOBALS['LSlog']['loggers'] = array (
  /**
   * Loggers permit to define different log parameters for specific components
   * of LdapSaisie (a class, an addon, ...). You could :
   *   - Enabled/disabled logs for this component with 'enabled' parameter
   *   - Set a specific log level for this component with 'enabled' parameter
   **/
  /*
  'LSurl' => array (
    'level' => 'DEBUG',
  ),
  'LSldap' => array (
    'level' => 'DEBUG',
  ),
  'LSlang' => array (
    'enabled' => false,
  ),
  */
);
$GLOBALS['LSlog']['level'] = 'INFO';  // TRACE, DEBUG, INFO, WARNING, ERROR, FATAL
$GLOBALS['LSlog']['enable'] = true;

define('NB_LSOBJECT_LIST',30);
define('NB_LSOBJECT_LIST_SELECT',20);
$GLOBALS['NB_LSOBJECT_LIST_CHOICES'] = array(30, 60, 100);

define('MAX_SEND_FILE_SIZE', 2000000);


// Default Javascript & CSS to include on all pages
$GLOBALS['defaultJSscripts']=array();
$GLOBALS['defaultCSSfiles']=array('light-blue.css');
