<?php
/*******************************************************************************
 * Copyright (C) 2021 Easter-eggs
 * http://ldapsaisie.org
 *
 * Author: See AUTHORS file in top-level directory.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

******************************************************************************/

// Activation du mode debug ?
$debug = false;

// Configuration de(s) l'annuaire(s) LDAP Supann
$supann_configs = array(
  array(
    /* non de l'établissement */
    'name' => 'Modifiez moi',
    /* non de domaine de l'établissement */
    'domain_name' => 'modifiez-moi.fr',
    /* configuration de la connexion à l'annuaire LDAP */
    'ldap_config' => array(
      /* adresse IP ou nom DNS du serveur LDAP */
      'host'     => '127.0.0.1',
      /* port d'écoute (devrait toujours être 389) */
      'port'     => 389,
      /* LDAPv3, ne pas changer */
      'version'  => 3,
      /* activation d'une connexion chiffrée TLS. Si true, il faut s'assurer
       * d'avoir un certificat valide sur le serveur LDAP, sinon ajouter cette
       * ligne à la fin de /etc/ldap/ldap.conf:
       *     TLS_REQCERT allow
      */
      'starttls' => false,

       /* nom de la base créée avec "newdb" */
      'basedn'   => 'dc=modifiez-moi,dc=fr',
      /* DN du compte applicatif utilisé par l'application, il faut juste modifier
      /* le suffixe dc=...  qui doit être égal à la valeur du basedn précédent */
      'binddn'   => 'uid=ldapsaisie,ou=sysaccounts,dc=modifiez-moi,dc=fr',
      /* mot de passe du compte applicatif choisi lors du "newdb" */
      'bindpw'   => 'modifiez-moi',

      /* ne pas toucher si vous ne savez pas ce que vous faîtes ...*/
      'options'  => array(),
      'filter'   => '(objectClass=*)',
      'scope'    => 'sub'
    ),
    'globals' => array(
      /* indiquer ici le DN de l'entité parente de l'établissement,
       * par exemple
       *    supannCodeEntite=QUELQUECHOSE,ou=structures,dc=quelquechose,dc=fr
       * où QUELQUECHOSE est le code choisi lors du "newdb"
       */
      'LS_SUPANN_ETABLISSEMENT_DN' => 'supannCodeEntite=MODIFIEZMOI,ou=structures,dc=modifiez-moi,dc=fr',
      /* code UAI indiqué lors du newdb */
      'LS_SUPANN_ETABLISSEMENT_UAI' => '{UAI}9990000X',
      /* format de construction des eduPersonPrincipalName */
      'LS_SUPANN_EPPN_FORMAT' => '%{uid}@modifiez-moi.fr',
      /* format de construction des eduPersonUniqueId (%{uniqueId} étant un ID unique généré aléatoirement) */
      'LS_SUPANN_EPUI_FORMAT' => '%{uniqueId}@modifiez-moi.fr',
      /* Domaines de messagerie gérés par l'établissement */
      'LS_SUPANN_MAIL_DOMAINS' => array('modifiez-moi.fr'),
    ),
  ),
);

// Activation de phpLdapAdmin (nécessite une installation manuelle)
define('LS_SUPANN_ENABLE_PHPLDAPADMIN', false);

// Activation du support de ppolicy (activé par défaut par sur les bases nouvellement
// crées par slapd-supann depuis la version 1.1)
define('LS_SUPANN_ENABLE_PPOLICY', true);
